Previz python API
=================

A python wrapper around `Previz REST API <https://previz.co>`_.

----

This is not a full wrapper yet: it only covers the functions needed by the integration plugins at the moment.
